MCPcopy Create free account
hub / github.com/ROCm/rocPRIM / block_id_kernel

Function block_id_kernel

test/rocprim/test_thread.cpp:141–148  ·  view source on GitHub ↗

Source from the content-addressed store, hash-verified

139__global__
140__launch_bounds__(1024)
141void block_id_kernel(unsigned int* device_output)
142{
143 unsigned int block_id = rocprim::flat_block_id<BlockSizeX, BlockSizeY, BlockSizeZ>();
144 if(threadIdx.x)
145 {
146 device_output[block_id] = block_id;
147 }
148}
149
150TYPED_TEST(RocprimThreadTests, FlatBlockID)
151{

Callers

nothing calls this directly

Calls

no outgoing calls

Tested by

no test coverage detected